#
# spec file for package libkate
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 SUSE Dominique Leuenberger, Amsterdam, Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without python2
Name:           libkate
Version:        0.4.1
Release:        lp152.4.7
Summary:        A karaoke and text codec for embedding in Ogg
License:        BSD-3-Clause
Group:          Productivity/Multimedia/Other
Url:            http://libkate.googlecode.com
Source:         http://libkate.googlecode.com/files/%{name}-%{version}.tar.gz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(ogg)
%if %{with python2}
BuildRequires:  python-base
%endif

%description
Kate is a codec for karaoke and text encapsulation for Ogg. Most of the
time, this would be multiplexed with audio/video to carry subtitles,
song lyrics (with or without karaoke data), etc, but doesn't have to be.
A possible use of a lone Kate stream would be an e-book. Moreover, the
motion feature gives Kate a powerful means to describe arbitrary curves,
so hand drawing of shapes can be achieved.

This was originally meant for karaoke use, but can be used for any
purpose. Motions can be attached to various semantics, like position,
color, etc, so scrolling or fading text can be defined.

%package -n %{name}1
Summary:        A karaoke and text codec for embedding in Ogg
Group:          System/Libraries

%description -n %{name}1
Kate is a codec for karaoke and text encapsulation for Ogg. Most of the
time, this would be multiplexed with audio/video to carry subtitles,
song lyrics (with or without karaoke data), etc, but doesn't have to be.
A possible use of a lone Kate stream would be an e-book. Moreover, the
motion feature gives Kate a powerful means to describe arbitrary curves,
so hand drawing of shapes can be achieved.

This was originally meant for karaoke use, but can be used for any
purpose. Motions can be attached to various semantics, like position,
color, etc, so scrolling or fading text can be defined.

%package -n liboggkate1
Summary:        A karaoke and text codec for embedding in Ogg
Group:          System/Libraries
Conflicts:      libkate1 < 0.4.1

%description -n liboggkate1
Kate is a codec for karaoke and text encapsulation for Ogg. Most of the
time, this would be multiplexed with audio/video to carry subtitles,
song lyrics (with or without karaoke data), etc, but doesn't have to be.
A possible use of a lone Kate stream would be an e-book. Moreover, the
motion feature gives Kate a powerful means to describe arbitrary curves,
so hand drawing of shapes can be achieved.

This was originally meant for karaoke use, but can be used for any
purpose. Motions can be attached to various semantics, like position,
color, etc, so scrolling or fading text can be defined.

%package devel
Summary:        A karaoke and text codec for embedding in Ogg - Development Files
Group:          Development/Libraries/C and C++
Requires:       %{name}1 = %{version}
Requires:       glibc-devel
Requires:       liboggkate1 = %{version}
Requires:       pkgconfig(ogg)

%description devel
Kate is a codec for karaoke and text encapsulation for Ogg. Most of the
time, this would be multiplexed with audio/video to carry subtitles,
song lyrics (with or without karaoke data), etc, but doesn't have to be.
A possible use of a lone Kate stream would be an e-book. Moreover, the
motion feature gives Kate a powerful means to describe arbitrary curves,
so hand drawing of shapes can be achieved.

This was originally meant for karaoke use, but can be used for any
purpose. Motions can be attached to various semantics, like position,
color, etc, so scrolling or fading text can be defined.

This package contains files for developers.

%package tools
Summary:        A karaoke and text codec for embedding in Ogg
Group:          Productivity/Multimedia/Other

%description tools
Kate is a codec for karaoke and text encapsulation for Ogg. Most of the
time, this would be multiplexed with audio/video to carry subtitles,
song lyrics (with or without karaoke data), etc, but doesn't have to be.
A possible use of a lone Kate stream would be an e-book. Moreover, the
motion feature gives Kate a powerful means to describe arbitrary curves,
so hand drawing of shapes can be achieved.

This was originally meant for karaoke use, but can be used for any
purpose. Motions can be attached to various semantics, like position,
color, etc, so scrolling or fading text can be defined.

%package -n python-katedj
Summary:        Editor and remixer for Kate streams in Ogg
Group:          Productivity/Multimedia/Other
Requires:       %{name}-tools = %{version}
Requires:       oggz-tools
Requires:       python-wxWidgets
Provides:       katedj = 0.4.1
Obsoletes:      katedj < 0.4.1
BuildArch:      noarch

%description -n python-katedj
KateDJ allows extracting Kate tracks embedded in an Ogg stream, editing
them, and rebuilding the Ogg stream after the Kate tracks are modified.

%prep
%setup -q

%build
echo 'HTML_TIMESTAMP=NO' >> doc/kate.doxygen.in
%configure \
        --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# Remove files that we install with %%doc
rm -rf %{buildroot}%{_datadir}/doc/%{name}/{AUTHORS,COPYING,ChangeLog,README,THANKS,html}
%if %{with python2}
%fdupes %{buildroot}%{python_sitelib}/kdj
%else
rm -rf %{buildroot}%{_mandir}/man1/KateDJ.1*
%endif

%check
make %{?_smp_mflags} check

%post -n %{name}1 -p /sbin/ldconfig
%postun -n %{name}1 -p /sbin/ldconfig

%files -n %{name}1
%doc AUTHORS COPYING ChangeLog README THANKS
%{_libdir}/%{name}.so.1*

%post -n liboggkate1 -p /sbin/ldconfig
%postun -n liboggkate1 -p /sbin/ldconfig

%files -n liboggkate1
%doc AUTHORS COPYING ChangeLog README THANKS
%{_libdir}/liboggkate.so.1*

%files devel
%doc doc/html/
%{_includedir}/kate/
%{_libdir}/%{name}.so
%{_libdir}/liboggkate.so
%{_libdir}/pkgconfig/kate.pc
%{_libdir}/pkgconfig/oggkate.pc

%files tools
%{_bindir}/katedec
%{_bindir}/kateenc
%{_bindir}/katalyzer
%{_mandir}/man1/katalyzer.1*
%{_mandir}/man1/katedec.1*
%{_mandir}/man1/kateenc.1*

%if %{with python2}
%files -n python-katedj
%{_bindir}/KateDJ
%{_mandir}/man1/KateDJ.1*
%{python2_sitelib}/kdj/
%endif

%changelog
* Wed Feb  7 2018 tchvatal@suse.com
- Make python2 dependency conditional bsc#1076407
- Remove few path based requires/etc
- Conflict properly with older libkate in order to allow migration
  and not clash with liboggkate1 library
* Wed May 28 2014 crrodriguez@opensuse.org
- Tell doxygen not to include timestamps to help build-compare
* Sun Mar  4 2012 davejplater@gmail.com
- Renamed kate-tools to libkate-tools.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Sep 25 2011 coolo@suse.com
- fix rename of sub packages
* Fri Sep 23 2011 davejplater@gmail.com
- Update to 0.4.1 and added download service.
- Split liboggkate into it's own package and updated baselibs.conf.
- Renamed katedj python-katedj in line with python naming policy.
- Upstream changes since 0.3.8 :
  * update bitstream and shared library versioning missed from 0.4.0
  * timed and object metadata support
  * fix various precision issues with large timestamps
  * fix KateDJ editor with newer versions of wxPython
  * katedec now tries to avoid escaping non ASCII glyphs
  * misc error handling improvements/fixes
  * misc build and documentation fixes
* Fri Sep 16 2011 andrea.turrini@gmail.com
- fix typos
* Fri Apr 29 2011 jw@novell.com
- Really removed "Other uncritical OpenSource License" from all the
  license fields and retained BSD3c.
* Wed Apr 27 2011 davejplater@gmail.com
- Removed "Other uncritical OpenSource License" from the license
  field and retained BSD3c.
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
- properly escaped commented macro (fix for RPMLINT warning)
* Wed Dec 29 2010 sbrabec@suse.cz
- Updated python-wxWidgets name.
* Thu Dec  9 2010 cristian.rodriguez@opensuse.org
- run make check
- fix -devel package dependencies
* Mon Sep 27 2010 dominique-vlc.suse@leuenberger.net
- katedj can only be noarch on openSUSE >= 1130. RPM in older
  versions does not support mixed arch packages.
* Sun Sep 26 2010 dimstar@opensuse.org
- Fix build on openSUSE 11.1 by defining the python_site* macros.
* Fri Sep 24 2010 reddwarf@opensuse.org
- Make katedj noarch.
- Add Requires for various oggz tools to katedj.
- Use fdupes.
* Tue Sep 21 2010 vuntz@opensuse.org
- Add python-base BuildRequires to build KateDJ, and create a
  katedj subpackage.
- Rename kate-utils to libkate-tools.
- Install the API documentation at a more standard place.
* Tue Sep 21 2010 dimstar@opensuse.org
- Clean up spec file for Factory inclusion.
* Wed Sep  8 2010 dimstar@opensuse.org
- Update to version 0.3.8:
  + various build fixes
  + KateDJ can now decode to LRC and SRT formats
  + add a missing check for memory allocation failure
  + fix a bug in SRT output when decoding more than one stream at a
    time
  + flush output so live encoding/decoding is possible without
    delay
  + katalyzer improvements in page/hole tracking
  + tools now recognize long options --help and --version
  + kateenc now adds an ENCODER comment by default
- Drop kate-png14.patch, upstream included.
* Tue Apr 20 2010 dimstar@opensuse.org
- Update to 0.3.7:
  + new encoding functions to specify timing in granule rate units
  + fix SRT timing precision problems
  + new -M option to kateenc to allow HTML-like markup in SRT files
  + allow the last event in an SRT file to not be followed by an
    empty line
- Added kate-png14.patch to fix build with libpng 1.4.
* Mon Aug 31 2009 dimstar@opensuse.org
- Update to 0.3.4
  + fix canvas size encoding/decoding on big endian hosts
* Sat May 30 2009 dimstar@opensuse.org
- Update to 0.3.3
  + recognize old oggz tools names in configure
  + remove unnecessary shebangs from python source
- Update to 0.3.2
  + increased robustness against corrupt/malicious streams
  + misc build and compatibility tweaks
  + fix py-compile invokation and older oggz tools names
